define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "tänä neljänneksenä",
	"field-quarter-short-relative+1": "ensi neljänneksenä",
	"field-tue-relative+-1": "viime tiistaina",
	"field-year": "vuosi",
	"dateFormatItem-Hm": "H.mm",
	"field-wed-relative+0": "tänä keskiviikkona",
	"field-wed-relative+1": "ensi keskiviikkona",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "minuutti",
	"field-month-narrow-relative+-1": "viime kk",
	"field-tue-narrow-relative+0": "tänä ti",
	"field-tue-narrow-relative+1": "ensi ti",
	"field-day-short-relative+-1": "eilen",
	"field-thu-short-relative+0": "tänä to",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "tänään",
	"field-day-short-relative+-2": "toissap.",
	"field-thu-short-relative+1": "ensi to",
	"field-day-relative+1": "huomenna",
	"field-week-narrow-relative+0": "tällä vk",
	"field-day-relative+2": "ylihuomenna",
	"field-week-narrow-relative+1": "ensi vk",
	"dateFormatItem-EBhms": "E h.mm.ss B",
	"field-wed-narrow-relative+-1": "viime ke",
	"field-year-narrow": "v",
	"field-era-short": "aikakausi",
	"field-year-narrow-relative+0": "tänä v",
	"field-tue-relative+0": "tänä tiistaina",
	"field-year-narrow-relative+1": "ensi v",
	"field-tue-relative+1": "ensi tiistaina",
	"field-weekdayOfMonth": "kuukauden viikonpäivä",
	"field-second-short": "s",
	"dateFormatItem-yyyyMM": "M.y G",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "kuukauden vk päivä",
	"field-week-relative+0": "tällä viikolla",
	"field-month-relative+0": "tässä kuussa",
	"field-week-relative+1": "ensi viikolla",
	"field-month-relative+1": "ensi kuussa",
	"field-sun-narrow-relative+0": "tänä su",
	"field-mon-short-relative+0": "tänä ma",
	"field-sun-narrow-relative+1": "ensi su",
	"field-mon-short-relative+1": "ensi ma",
	"field-second-relative+0": "nyt",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "kuukauden viikko",
	"field-month-short": "kk",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-day": "päivä",
	"field-dayOfYear-short": "vuodenpv",
	"field-year-relative+-1": "viime vuonna",
	"field-sat-short-relative+-1": "viime la",
	"field-hour-relative+0": "tämän tunnin aikana",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-second-short-relative+0": "nyt",
	"field-wed-relative+-1": "viime keskiviikkona",
	"dateTimeFormat-medium": "{1} 'klo' {0}",
	"field-sat-narrow-relative+-1": "viime la",
	"field-second": "sekunti",
	"dateFormatItem-yyyyMMMMccccd": "cccc d. MMMM y G",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "tunnin sisällä",
	"field-quarter": "neljännesvuosi",
	"field-week-short": "vk",
	"field-day-narrow-relative+0": "tänään",
	"field-day-narrow-relative+1": "huom.",
	"field-day-narrow-relative+2": "ylihuom.",
	"field-tue-short-relative+0": "tänä ti",
	"field-tue-short-relative+1": "ensi ti",
	"field-month-short-relative+-1": "viime kk",
	"field-mon-relative+-1": "viime maanantaina",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "kuukausi",
	"field-day-narrow": "pv",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "vuorokaudenaika",
	"field-sat-short-relative+0": "tänä la",
	"field-sat-short-relative+1": "ensi la",
	"dateFormat-medium": "d.M.y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-yyyyM": "L.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "tänä maanantaina",
	"field-day-narrow-relative+-1": "eilen",
	"field-year-short": "v",
	"field-mon-relative+1": "ensi maanantaina",
	"field-day-narrow-relative+-2": "toissap.",
	"field-quarter-relative+-1": "viime neljännesvuonna",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "vuorokaudenaika",
	"field-week-narrow-relative+-1": "viime vk",
	"field-dayOfYear": "vuodenpäivä",
	"field-sat-relative+-1": "viime lauantaina",
	"dateTimeFormat-long": "{1} 'klo' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "tunti",
	"field-minute-narrow-relative+0": "minuutin sisällä",
	"dateFormat-full": "cccc d. MMMM y G",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-Hms": "H.mm.ss",
	"field-quarter-short": "neljännes",
	"field-sat-narrow-relative+0": "tänä la",
	"field-fri-relative+0": "tänä perjantaina",
	"field-sat-narrow-relative+1": "ensi la",
	"field-fri-relative+1": "ensi perjantaina",
	"dateFormatItem-EBhm": "E h.mm B",
	"field-month-narrow-relative+0": "tässä kk",
	"field-month-narrow-relative+1": "ensi kk",
	"field-sun-short-relative+0": "tänä su",
	"field-sun-short-relative+1": "ensi su",
	"field-week-relative+-1": "viime viikolla",
	"field-quarter-short-relative+-1": "viime neljänneksenä",
	"dateFormatItem-Ehm": "E h.mm a",
	"field-minute-short-relative+0": "minuutin sisällä",
	"field-quarter-relative+0": "tänä neljännesvuonna",
	"field-minute-relative+0": "tämän minuutin aikana",
	"field-quarter-relative+1": "ensi neljännesvuonna",
	"field-wed-short-relative+-1": "viime ke",
	"dateFormat-short": "d.M.y GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "viime v",
	"field-thu-short-relative+-1": "viime to",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "viime ma",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "viime to",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H",
	"field-weekOfMonth-short": "kuukauden vk",
	"field-tue-narrow-relative+-1": "viime ti",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "tänä ke",
	"field-wed-short-relative+1": "ensi ke",
	"field-sun-relative+-1": "viime sunnuntaina",
	"dateTimeFormat-full": "{1} 'klo' {0}",
	"field-second-narrow-relative+0": "nyt",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "viikonpäivä",
	"field-day-short-relative+0": "tänään",
	"field-quarter-narrow-relative+0": "tänä nelj.",
	"field-day-short-relative+1": "huom.",
	"field-sat-relative+0": "tänä lauantaina",
	"field-quarter-narrow-relative+1": "ensi nelj.",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "ylihuom.",
	"field-sat-relative+1": "ensi lauantaina",
	"field-week-short-relative+0": "tällä vk",
	"field-week-short-relative+1": "ensi vk",
	"field-dayOfYear-narrow": "vuodenpv",
	"field-month-short-relative+0": "tässä kk",
	"field-month-short-relative+1": "ensi kk",
	"field-weekdayOfMonth-short": "kuukauden vk päivä",
	"dateFormatItem-MEd": "E d.M.",
	"field-zone-narrow": "aikavyöhyke",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "tänä to",
	"field-sun-narrow-relative+-1": "viime su",
	"field-mon-short-relative+-1": "viime ma",
	"field-thu-narrow-relative+1": "ensi to",
	"field-thu-relative+0": "tänä torstaina",
	"field-thu-relative+1": "ensi torstaina",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "viime pe",
	"field-thu-relative+-1": "viime torstaina",
	"field-week": "viikko",
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "tänä ke",
	"field-wed-narrow-relative+1": "ensi ke",
	"field-quarter-narrow-relative+-1": "viime nelj.",
	"field-year-short-relative+0": "tänä v",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-dayperiod-short": "vuorokaudenaika",
	"field-year-short-relative+1": "ensi v",
	"field-fri-short-relative+0": "tänä pe",
	"field-fri-short-relative+1": "ensi pe",
	"field-week-short-relative+-1": "viime vk",
	"field-hour-narrow-relative+0": "tunnin sisällä",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t",
	"field-zone-short": "aikavyöhyke",
	"field-month-narrow": "kk",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "viime pe",
	"field-year-relative+0": "tänä vuonna",
	"field-year-relative+1": "ensi vuonna",
	"field-era-narrow": "aikakausi",
	"field-fri-relative+-1": "viime perjantaina",
	"dateFormatItem-Bhms": "h.mm.ss B",
	"field-tue-short-relative+-1": "viime ti",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "tänä ma",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-narrow-relative+1": "ensi ma",
	"field-year-short-relative+-1": "viime v",
	"field-zone": "aikavyöhyke",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"field-weekOfMonth-narrow": "kuukauden vk",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"field-weekday-narrow": "viikonpäivä",
	"field-quarter-narrow": "nelj.",
	"field-sun-short-relative+-1": "viime su",
	"field-day-relative+-1": "eilen",
	"field-day-relative+-2": "toissa päivänä",
	"field-weekday-short": "viikonpäivä",
	"dateFormatItem-Bhm": "h.mm B",
	"field-sun-relative+0": "tänä sunnuntaina",
	"field-sun-relative+1": "ensi sunnuntaina",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "pv",
	"field-week-narrow": "vk",
	"field-era": "aikakausi",
	"field-fri-narrow-relative+0": "tänä pe",
	"field-fri-narrow-relative+1": "ensi pe"
}
//end v1.x content
);